@@ -15,6 +15,8 @@
 
 import six
 
+from shade import exc
+
 NON_CALLABLES = (six.string_types, bool, dict, int, list, type(None))
 
 
@@ -93,6 +95,7 @@ def get_groups_from_server(cloud, server, server_vars):
 
 def get_hostvars_from_server(cloud, server, mounts=None):
     server_vars = obj_to_dict(server)
+    server_vars.pop('links', None)
 
     # Fist, add an IP address
     server_vars['public_v4'] = get_server_public_ip(server)
@@ -111,23 +114,28 @@ def get_hostvars_from_server(cloud, server, mounts=None):
     flavor_name = cloud.get_flavor_name(flavor_id)
     if flavor_name:
         server_vars['flavor']['name'] = flavor_name
+    server_vars['flavor'].pop('links', None)
 
     # OpenStack can return image as a string when you've booted from volume
-    if unicode(server.image) == server.image:
+    if str(server.image) == server.image:
         image_id = server.image
+        server_vars['image'] = dict(id=image_id)
     else:
         image_id = server.image.get('id', None)
     if image_id:
         image_name = cloud.get_image_name(image_id)
         if image_name:
             server_vars['image']['name'] = image_name
+    server_vars['image'].pop('links', None)
 
     volumes = []
-    for vol in cloud.get_volumes(server):
-        volume = obj_to_dict(vol)
-        # Make things easier to consume elsewhere
-        volume['device'] = volume['attachments'][0]['device']
-        volumes.append(volume)
+    try:
+        for volume in cloud.get_volumes(server):
+            # Make things easier to consume elsewhere
+            volume['device'] = volume['attachments'][0]['device']
+            volumes.append(volume)
+    except exc.OpenStackCloudException:
+        pass
     server_vars['volumes'] = volumes
     if mounts:
         for mount in mounts:
@@ -160,11 +168,25 @@ def obj_to_dict(obj):
     return instance
 
 
+def obj_list_to_dict(list):
+    """Enumerate through lists of objects and return lists of dictonaries.
+
+    Some of the objects returned in OpenStack are actually lists of objects,
+    and in order to expose the data structures as JSON, we need to facilitate
+    the conversion to lists of dictonaries.
+    """
+    new_list = []
+    for obj in list:
+        new_list.append(obj_to_dict(obj))
+    return new_list
+
+
 def warlock_to_dict(obj):
     # glanceclient v2 uses warlock to construct its objects. Warlock does
     # deep black magic to attribute look up to support validation things that
     # means we cannot use normal obj_to_dict
     obj_dict = {}
-    for key in obj.keys():
-        obj_dict[key] = obj[key]
+    for (key, value) in obj.items():
+        if isinstance(value, NON_CALLABLES) and not key.startswith('_'):
+            obj_dict[key] = value
     return obj_dict
