@@ -33,10 +33,10 @@ class TestCompute(base.TestCase):
         self.nova = self.cloud.nova_client
         self.flavor = pick_flavor(self.nova.flavors.list())
         if self.flavor is None:
-            self.addDetail('pick_flavor', 'no sensible flavor available')
+            self.assertFalse('no sensible flavor available')
         self.image = pick_image(self.nova.images.list())
         if self.image is None:
-            self.addDetail('pick_image', 'no sensible image available')
+            self.assertFalse('no sensible image available')
 
     def _cleanup_servers(self):
         for i in self.nova.servers.list():
@@ -57,3 +57,15 @@ class TestCompute(base.TestCase):
                                  image=self.image, flavor=self.flavor)
         server_deleted = self.cloud.delete_server('test_delete_server')
         self.assertIsNone(server_deleted)
+
+    def test_get_image_id(self):
+        self.assertEqual(
+            self.image.id, self.cloud.get_image_id(self.image.id))
+        self.assertEqual(
+            self.image.id, self.cloud.get_image_id(self.image.name))
+
+    def test_get_image_name(self):
+        self.assertEqual(
+            self.image.name, self.cloud.get_image_name(self.image.id))
+        self.assertEqual(
+            self.image.name, self.cloud.get_image_name(self.image.name))
